pyLife Cookbook
===============

The pyLife Cookbook aggregates some demo notebooks that show how pyLife is
meant to be used for some use cases.  Here find the statically rendered HTML
pages.  The notebook files are available in the ``/demos`` `directory
<https://github.com/boschresearch/pylife/tree/develop/demos>`_ of
pyLife's codebase.

If you want to try out the notebooks without installing anything on your
computer, you can use `MyBinder
<https://mybinder.org/v2/gh/boschresearch/pylife/develop?labpath=demos%2Findex.ipynb>`_.

.. toctree::
   :maxdepth: 1
   :caption: Life time and reliability

   demos/lifetime_calc.nblink

.. toctree::
   :maxdepth: 1
   :caption: Material Laws

   demos/ramberg_osgood.nblink

.. toctree::
   :maxdepth: 1
   :caption: Material Data

   demos/woehler_analyzer.nblink

.. toctree::
   :maxdepth: 1
   :caption: FEM based methods

   demos/hotspot_beam.nblink
   demos/stress_gradient.nblink
   demos/local_stress_with_FE.nblink

.. toctree::
   :maxdepth: 1
   :caption: Tools

   demos/psd_optimizer.nblink
   demos/time_series_handling.nblink
